Invenio modules (alpha) — Invenio 3.4.0a8 documentation

# Invenio modules (alpha)

Note

These modules are in alpha. The modules are being used in production systems but are most likely subject to changes and are missing documentation.

In addition to above bundles, we have a number of other individual modules which are all being used in production systems, but which are likely subject to change prior to final release and in most cases are missing documentation.

- invenio-accounts-rest

    - REST APIs for account management.

- invenio-charts-js

    - AngularJS application for producing charts.

- invenio-csl-js

    - AngularJS application for rendering citation strings via the records REST API and the CSL REST API.

- invenio-csl-rest

    - REST API for retrieving Citation Style Language (CSL) style files.

- invenio-github

    - GitHub integration with automatic archiving of new releases in Invenio.

- invenio-openaire

    - Integration with OpenAIRE, including support for harvesting Open Funder Regsitry and the OpenAIRE grants database, as well as REST APIs for funders and grants.

- invenio-opendefinition

    - REST API for licenses from OpenDefinition and SPDX.

- invenio-pages

    - Static pages module for Invenio.

- invenio-pidrelations

    - Persistent identifier relations management to support e.g. DOI versioning.

- invenio-previewer-ispy

    - ISPY previewer.

- invenio-query-parser

    - Invenio v1 compatible query parser for Invenio v3. Note the module is GPL licensed due to a GPL-licensed dependency.

- invenio-s3

    - Support for the S3 storage protocol in Invenio.

- invenio-saml

    - SAML support for Invenio.

- invenio-sequencegenerator

    - Module for minting and tracking multiple sequences for e.g. report numbers, journals etc.

- invenio-sse

    - Server-Sent Events (SSE) integration in Invenio.

- invenio-webhooks

    - REST API for receiving and processing webhook calls from third-party services.

- invenio-xrootd

    - Support for the storage protocol XRootD in Invenio.

- react-searchkit

    - Modular React library for implementing search interfaces on top of Invenio, Elasticsearch or other search APIs. Replacement for Invenio-Search-JS.